@@ -144,7 +144,7 @@ class Command(BaseCommand):
         repetidas = 0
         descargadas = 0
         total = 0
-        thumbs = [60, 200, 750, 1000]
+        thumbs = [200, 750, 1000]
         if storage == 'dropbox':
             srcdir = os.path.join(conf.PROJECT_DIR, 'media', 'uploads', 'dropbox')
         if storage == 'file':
@@ -188,7 +188,6 @@ class Command(BaseCommand):
                     nombre_imagen = "%s_1%s" % (slugify(str(os.path.splitext(os.path.basename(filepath))[0]).replace('/', '').replace(' ','_').replace(':','-')),
                                                      str(os.path.splitext(os.path.basename(filepath))[1]))
                     print "      Duplicada en disco, cambiado nombre a: %s" % nombre_imagen
-                    descargadas += 1
                 img = download(client, file, nombre_imagen, srcdir, destdir, debug)
                 print "      Guardada: %s/%s" % (destdir, nombre_imagen)
 
@@ -204,6 +203,7 @@ class Command(BaseCommand):
                                     capture_date=capture_data,
                                     status=True)
                 im.save()
+                descargadas += 1
                 print "      Agregada a bbdd (%s)" % im.origen
 
                 # Abrimos imagen para modificaciones
@@ -211,6 +211,11 @@ class Command(BaseCommand):
                 im2 = img_rotate(im2) # Rotar
                 im2.save(destdir + '/' + nombre_imagen)
 
+                # Creamos thumbs
+                for thumb in thumbs:
+                    print "      Thumb %sx%s" % (thumb, thumb)
+                    im = get_thumbnail(im, "%sx%s" % (thumb, thumb))
+
             total += 1
 
         print ""
